<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>CheckUpdate</name>
    <message>
        <source>Last check: </source>
        <translation>最終確認: </translation>
    </message>
</context>
<context>
    <name>QuitTestingChannelDialog</name>
    <message>
        <source>If you exit the beta program, you will no longer receive beta updates.</source>
        <translation>ベータプログラムから退出すると、ベータ版の受信を停止します。</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>UpdateControl</name>
    <message>
        <source>View Update Log</source>
        <translation>アップデートログを表示</translation>
    </message>
</context>
<context>
    <name>UpdateHistoryDialog</name>
    <message>
        <source>Update History</source>
        <translation>アップデート履歴</translation>
    </message>
    <message>
        <source>No update history</source>
        <translation>アップデートの履歴はありません</translation>
    </message>
    <message>
        <source>System Updates</source>
        <translation>システムアップデート</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>セキュリティアップデート</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and security updates</source>
        <translation>新しい機能、品質改善、セキュリティのアップデートが含まれます</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>セキュリティのアップデートが含まれます</translation>
    </message>
    <message>
        <source>Installation date:</source>
        <translation>インストール日:</translation>
    </message>
</context>
<context>
    <name>UpdateList</name>
    <message>
        <source>View Details</source>
        <translation>詳細を表示</translation>
    </message>
    <message>
        <source>Release time:</source>
        <translation>リリース時刻:</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>折りたたむ</translation>
    </message>
    <message>
        <source>Version:</source>
        <translation>バージョン:</translation>
    </message>
</context>
<context>
    <name>UpdateLogDialog</name>
    <message>
        <source>Update Log</source>
        <translation>アップデートログ</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
    <message>
        <source>Export to desktop</source>
        <translation>デスクトップにエクスポート</translation>
    </message>
</context>
<context>
    <name>UpdateLogHelper</name>
    <message>
        <source>NONE</source>
        <translation>無し</translation>
    </message>
    <message>
        <source>LOW</source>
        <translation>低</translation>
    </message>
    <message>
        <source>MEDIUM</source>
        <translation>中</translation>
    </message>
    <message>
        <source>HIGH</source>
        <translation>高</translation>
    </message>
    <message>
        <source>CRITICAL</source>
        <translation>緊急</translation>
    </message>
    <message>
        <source>critical-risk</source>
        <translation>緊急のリスク</translation>
    </message>
    <message>
        <source>high-risk</source>
        <translation>高いリスク</translation>
    </message>
    <message>
        <source>medium-risk</source>
        <translation>中程度のリスク</translation>
    </message>
    <message>
        <source>low-risk</source>
        <translation>低いリスク</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <source>This update fixes</source>
        <translation>アップデートの修正内容</translation>
    </message>
    <message>
        <source>vulnerabilities</source>
        <translation>脆弱性</translation>
    </message>
    <message>
        <source>vulnerability</source>
        <translation>脆弱性</translation>
    </message>
    <message>
        <source>%1 of %2 %3</source>
        <translation>%2 %3の%1</translation>
        <extra-content_explain>`数字+%`会在代码中替换为字符串，例如：3 of high-risk vulnerabilities；各语言需要根据实际情况增加空格(例如：中文没有空格，英文有空格)</extra-content_explain>
    </message>
    <message>
        <source>, </source>
        <translation>, </translation>
        <extra-content_explain>中文逗号不需要空格，英文逗号需要空格For more details, please visit</extra-content_explain>
    </message>
    <message>
        <source>for more details, please visit </source>
        <translation>詳細情報はこちら </translation>
        <extra-content_explain>这句话后面会带上一个超链接，各语言自行决定末尾需不需要加空格</extra-content_explain>
    </message>
</context>
<context>
    <name>UpdateModel</name>
    <message>
        <source>Checking for updates, please wait…</source>
        <translation>アップデートを確認しています。しばらくお待ちください…</translation>
    </message>
    <message>
        <source>Your system is up to date</source>
        <translation>すでに最新の状態です</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>不明なエラー</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please free up %1 disk space first.</source>
        <translation>アップデートをダウンロードできませんでした。%1の空き容量を増やしてください。</translation>
    </message>
    <message>
        <source>Dependency error, failed to detect the updates</source>
        <translation>依存関係エラーが発生したため、アップデートを検出できませんでした</translation>
    </message>
    <message>
        <source>Please check your network and try again.</source>
        <translation>ネットワーク接続を確認してもう一度お試しください。</translation>
    </message>
    <message>
        <source>Downloading updates failed. Please check your network and try again.</source>
        <translation>アップデートをダウンロードできませんでした。ネットワーク接続を確認してもう一度お試しください。</translation>
    </message>
    <message>
        <source>Unable to perform system backup. If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>システムをバックアップできません。アップデートを続行すると、後で古いシステムにロールバックすることができなくなります。</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>アップデートを続行すると現在のシステムにロールバックできなくなります。</translation>
    </message>
    <message>
        <source>Insufficient disk space</source>
        <translation>ディスクの空き領域が不足しています</translation>
    </message>
    <message>
        <source>DPKG error</source>
        <translation>DPKGエラー</translation>
    </message>
    <message>
        <source>File missing</source>
        <translation>ファイルが不足しています</translation>
    </message>
    <message>
        <source>Service connection is abnormal, please check the network and try again</source>
        <translation>アップデートサービスへの接続が異常です。ネットワークをご確認のうえ、もう一度お試しください</translation>
    </message>
    <message>
        <source>The repository source configuration is not valid, please check and try again.</source>
        <translation>リポジトリソースの設定が正しくありません。ご確認のうえ、もう一度お試しください。</translation>
    </message>
    <message>
        <source>Check Again</source>
        <translation>もう一度確認する</translation>
    </message>
    <message>
        <source>Privacy Policy</source>
        <translation>プライバシーポリシー</translation>
    </message>
    <message>
        <source>To use this software, you must accept the %1 that accompanies software updates.</source>
        <translation>このソフトウェアを使用するには、%1のソフトウェアアップデートに付随する内容に同意する必要があります。</translation>
    </message>
    <message>
        <source>Turn on the switches under Update Content to get better experiences</source>
        <translation>より良い体験を得るために、コンテンツのアップデートを有効にしてください</translation>
    </message>
    <message>
        <source>Your system is not activated, and it failed to connect to update services</source>
        <translation>システムがアクティベートされていないため、アップデートサービスに接続できませんでした</translation>
    </message>
    <message>
        <source>The system updates are disabled. Please contact your administrator for help</source>
        <translation>システムアップデートが無効化されています。詳細はシステム管理者にお問い合わせください</translation>
    </message>
    <message>
        <source>The system has enabled auto recovery function and does not support updates. If you have any questions, please contact the enterprise administrator</source>
        <translation>自動リカバリ機能が有効になっているため、アップデートを利用できません。詳細はシステム管理者にお問い合わせください</translation>
    </message>
</context>
<context>
    <name>UpdateSelectDialog</name>
    <message>
        <source>The updates have been already downloaded. What do you want to do?</source>
        <translation>更新は既にダウンロードされています。行いたい操作を選択してください。</translation>
    </message>
    <message>
        <source>Silent Installation</source>
        <translation>サイレントインストール</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>アップデートして再起動</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>アップデートしてシャットダウン</translation>
    </message>
</context>
<context>
    <name>UpdateSetting</name>
    <message>
        <source>Smart Mirror Switch</source>
        <translation>効率的なミラーの切り替え</translation>
    </message>
    <message>
        <source>Update Type</source>
        <translation>アップデートタイプ</translation>
    </message>
    <message>
        <source>Function Updates</source>
        <translation>機能アップデート</translation>
    </message>
    <message>
        <source>Delivers a cumulative update including new features, quality updates, and  security updates</source>
        <translation>新しい機能、品質改善、セキュリティのアップデートが配信されます</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>セキュリティアップデート</translation>
    </message>
    <message>
        <source>Delivers security updates</source>
        <translation>セキュリティのアップデートが配信されます</translation>
    </message>
    <message>
        <source>Third-party Updates</source>
        <translation>サードパーティのアップデート</translation>
    </message>
    <message>
        <source>Delivers  updates for additional repository sources</source>
        <translation>追加のリポジトリのアップデートが配信されます</translation>
    </message>
    <message>
        <source>Limit Speed</source>
        <translation>速度の制限</translation>
    </message>
    <message>
        <source>Limit Setting</source>
        <translation>設定速度</translation>
    </message>
    <message>
        <source>Auto Download</source>
        <translation>自動ダウンロード</translation>
    </message>
    <message>
        <source>Enabling &quot;Auto Download Updates&quot; will automatically download updates when connected to the internet</source>
        <translation>自動ダウンロードを有効にすると、インターネットへの接続中に自動でアップデートをダウンロードします</translation>
    </message>
    <message>
        <source>Download when Inactive</source>
        <translation>アクティブ時間外にダウンロードする</translation>
    </message>
    <message>
        <source>Start at</source>
        <translation>開始時刻</translation>
    </message>
    <message>
        <source>End at</source>
        <translation>終了時刻</translation>
    </message>
    <message>
        <source>Advanced Settings</source>
        <translation>詳細設定</translation>
    </message>
    <message>
        <source>Updates Notification</source>
        <translation>アップデートの通知</translation>
    </message>
    <message>
        <source>Clear Package Cache</source>
        <translation>パッケージキャッシュを消去</translation>
    </message>
    <message>
        <source>Update History</source>
        <translation>アップデートログ</translation>
    </message>
    <message>
        <source>View</source>
        <translation>表示</translation>
    </message>
    <message>
        <source>Join Internal Testing Channel</source>
        <translation>内部テストチャンネルに参加</translation>
    </message>
    <message>
        <source>Click here to complete the application</source>
        <translation>ここをクリックして承認してください</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>展開</translation>
    </message>
    <message>
        <source>Forum users at level 2 and above can join the beta test to receive the latest updates.</source>
        <translation>Level 2以上のフォーラムユーザーがベータテストに参加し最新のアップデートを受け取ることができます。</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>折りたたむ</translation>
    </message>
    <message>
        <source>Only numbers between 1-99999 are allowed</source>
        <translation>1から99999の間で入力してください</translation>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>System Updates</source>
        <translation>システムアップデート</translation>
    </message>
    <message>
        <source>Fixed some known bugs and security vulnerabilities</source>
        <translation>既知のバグとセキュリティ脆弱性の修正</translation>
    </message>
    <message>
        <source>Security Updates</source>
        <translation>セキュリティアップデート</translation>
    </message>
    <message>
        <source>Third-party Repositories</source>
        <translation>サードパーティのリポジトリ</translation>
    </message>
    <message>
        <source>updatelog</source>
        <translation>アップデートログ</translation>
    </message>
    <message>
        <source>Log export failed, please try again</source>
        <translation>ログをエクスポートできませんでした。もう一度お試しください</translation>
    </message>
    <message>
        <source>The log has been exported to the desktop</source>
        <translation>ログがデスクトップにエクスポートされました</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>アップデート</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>アップデートをインストールするには、電源に接続してください。</translation>
    </message>
</context>
<context>
    <name>update</name>
    <message>
        <source>System Update</source>
        <translation>システムアップデート</translation>
    </message>
    <message>
        <source>System update and upgrade</source>
        <translation>システムアップデートとアップグレード</translation>
    </message>
</context>
<context>
    <name>updateMain</name>
    <message>
        <source>Update Settings</source>
        <translation>アップデートの設定</translation>
    </message>
    <message>
        <source>Installing</source>
        <translation>インストールしています</translation>
    </message>
    <message>
        <source>Update download completed</source>
        <translation>アップデートのダウンロードが完了しました</translation>
    </message>
    <message>
        <source>Install updates</source>
        <translation>アップデートをインストール</translation>
    </message>
    <message>
        <source>Update size: </source>
        <translation>アップデートサイズ:</translation>
    </message>
    <message>
        <source>Update download failed</source>
        <translation>アップデートをダウンロードできませんでした</translation>
    </message>
    <message>
        <source>Downloading updates...</source>
        <translation>アップデートをダウンロードしています...</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>ダウンロードしています</translation>
    </message>
    <message>
        <source>Configure Update settings、Security Updates、Auto Download Updates and Updates Notification</source>
        <translation>アップデートの設定、セキュリティアップデート、自動ダウンロードとアップデートの通知を設定できます</translation>
    </message>
    <message>
        <source>Reboot now</source>
        <translation>今すぐ再起動</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>ダウンロード</translation>
    </message>
    <message>
        <source>Installing updates...</source>
        <translation>アップデートをインストールしています...</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation>再試行</translation>
    </message>
    <message>
        <source>Continue Update</source>
        <translation>アップデートを続行</translation>
    </message>
    <message>
        <source>Updates Available</source>
        <translation>アップデート利用可能</translation>
    </message>
    <message>
        <source>Installation update failed</source>
        <translation>アップデートをインストールできませんでした</translation>
    </message>
    <message>
        <source>To ensure proper functioning of your system and applications, please restart your computer after the update</source>
        <translation>システムとアプリケーションを十分に機能させるため、アップデート後はコンピューターを再起動してください</translation>
    </message>
    <message>
        <source>Backing up in progress...</source>
        <translation>バックアップしています…</translation>
    </message>
    <message>
        <source>Backing up in progress</source>
        <translation>バックアップしています</translation>
    </message>
    <message>
        <source>Backup failed</source>
        <translation>バックアップできませんでした</translation>
    </message>
    <message>
        <source>Update installation successful</source>
        <translation>アップデートが正常にインストールされました</translation>
    </message>
    <message>
        <source>If you continue the updates, you cannot roll back to the old system later.</source>
        <translation>アップデートを続行すると、後で古いシステムにロールバックすることができなくなります。</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>もう一度試す</translation>
    </message>
    <message>
        <source>Proceed to Update</source>
        <translation>アップデートを続行</translation>
    </message>
    <message>
        <source>The battery capacity is lower than 60%. To get successful updates, please plug in.</source>
        <translation>バッテリー残量が60%以下です。正常にアップデートを実行するため、電源に接続してください。</translation>
    </message>
</context>
</TS>